ConfigError

Enum ConfigError 

pub enum ConfigError {
    ParseError {
        source: BoxedErrorSource,
        args: Vec<String>,
    },
    ElectionTimeout {
        min: u64,
        max: u64,
    },
    MaxPayloadIs0,
    ElectionTimeoutLTHeartBeat {
        election_timeout_min: u64,
        heartbeat_interval: u64,
    },
    HeartbeatMinIntervalTooLarge {
        election_timeout_min: u64,
        heartbeat_interval: u64,
        heartbeat_min_interval: u64,
    },
    QuorumLossProbeIntervalTooSmall {
        election_timeout_max: u64,
        probe_interval: u64,
    },
    InvalidSnapshotPolicy {
        invalid: String,
        syntax: String,
    },
    InvalidNumber {
        invalid: String,
        reason: String,
    },
    InvalidBackoff(ParseError),
}
Error variants related to configuration.

Since: 0.10.0: added quorum-loss inactivity validation error

Variants



ParseError

Failed to parse configuration from command-line arguments.

Since: 0.10.0: source from AnyError to BoxedErrorSource

Fields

source: BoxedErrorSource

The underlying parse error.

args: Vec<String>

The arguments that failed to parse.



ElectionTimeout

The min election timeout is not smaller than the max election timeout.

Fields

min: u64

Minimum election timeout value.

max: u64

Maximum election timeout value.



MaxPayloadIs0

The max_payload_entries configuration must be greater than 0.



ElectionTimeoutLTHeartBeat

Election timeout must be greater than heartbeat interval.

Fields

election_timeout_min: u64

Minimum election timeout value.

heartbeat_interval: u64

Heartbeat interval value.



HeartbeatMinIntervalTooLarge

Heartbeat suppression must not delay a heartbeat past a follower’s election timeout.

Since: 0.10.0

Fields

election_timeout_min: u64

Minimum election timeout value.

heartbeat_interval: u64

Heartbeat interval value.

heartbeat_min_interval: u64

Minimum interval between two heartbeats to the same follower.



QuorumLossProbeIntervalTooSmall

The probe interval must leave time for follower lease expiry and an election.

Since: 0.10.0: added quorum-loss inactivity validation

Fields

election_timeout_max: u64

Maximum election timeout in milliseconds.

probe_interval: u64

Configured heartbeat phase interval in milliseconds.



InvalidSnapshotPolicy

Invalid snapshot policy string format.

Fields

invalid: String

The invalid policy string provided.

syntax: String

The expected syntax format.



InvalidNumber

Failed to parse a number from string.

Fields

invalid: String

The invalid number string.

reason: String

The reason for the parse failure.



InvalidBackoff(ParseError)

Invalid backoff policy string.

See backoff_series::BackoffSeries::parse for the expected format.

Since: 0.10.0