pub enum ConfigError {
ParseError {
source: BoxedErrorSource,
args: Vec<String>,
},
ElectionTimeout {
min: u64,
max: u64,
},
MaxPayloadIs0,
ElectionTimeoutLTHeartBeat {
election_timeout_min: u64,
heartbeat_interval: u64,
},
HeartbeatMinIntervalTooLarge {
election_timeout_min: u64,
heartbeat_interval: u64,
heartbeat_min_interval: u64,
},
QuorumLossProbeIntervalTooSmall {
election_timeout_max: u64,
probe_interval: u64,
},
InvalidSnapshotPolicy {
invalid: String,
syntax: String,
},
InvalidNumber {
invalid: String,
reason: String,
},
InvalidBackoff(ParseError),
}Expand description
Error variants related to configuration.
Since: 0.10.0: added quorum-loss inactivity validation error
Variants
ParseError
Failed to parse configuration from command-line arguments.
Since: 0.10.0: source from AnyError to BoxedErrorSource
Fields
source: BoxedErrorSourceThe underlying parse error.
ElectionTimeout
The min election timeout is not smaller than the max election timeout.
MaxPayloadIs0
The max_payload_entries configuration must be greater than 0.
ElectionTimeoutLTHeartBeat
Election timeout must be greater than heartbeat interval.
Fields
HeartbeatMinIntervalTooLarge
Heartbeat suppression must not delay a heartbeat past a follower’s election timeout.
Since: 0.10.0
Fields
QuorumLossProbeIntervalTooSmall
The probe interval must leave time for follower lease expiry and an election.
Since: 0.10.0: added quorum-loss inactivity validation
Fields
InvalidSnapshotPolicy
Invalid snapshot policy string format.
Fields
InvalidNumber
Failed to parse a number from string.
InvalidBackoff(ParseError)
Invalid backoff policy string.
See backoff_series::BackoffSeries::parse for the expected format.
Since: 0.10.0